module Character exposing (..)

import Sphere exposing (Sphere)
import BoundedInt exposing (BoundedInt)
import Creation exposing (CreationPoints)
import Stats exposing (Stats)

type alias Character =
    { name : String
    , creationPoints : CreationPoints
    , stats : Stats
    }

new : Character
new =
    { name = "Default Name"
    , creationPoints = Creation.new
    , stats = Stats.new
    }

changeName : Character -> String -> Character
changeName character newName =
    if ( newName == "")
    then
        character
    else
        { character | name = newName }

changeSphere : Character -> Sphere -> Character
changeSphere character sphere =
    let
        maybeOldDots = Sphere.getDotsOfSphereInList character.stats.spheres sphere.name
        difference = case maybeOldDots of
            Nothing -> 0
            Just oldDots ->
                if sphere.dots.value > character.stats.arete.value
                then character.stats.arete.value - oldDots.value
                else sphere.dots.value - oldDots.value
    in
        case maybeOldDots of
            Nothing -> character
            Just oldDots ->
                let
                    buyAmount = min difference character.creationPoints.spheres
                in
                    { character
                    | creationPoints = Creation.buySphere character.creationPoints buyAmount
                    , stats = Stats.changeSphere character.stats ( Sphere.changeDotsOfSphereTo sphere ( oldDots.value + buyAmount ) )
                    }